@@ -26,16 +26,20 @@ def date_range(start_date, end_date):
         start_date = start_date.date()
     if isinstance(end_date, datetime.datetime):
         end_date = end_date.date()
-    
+
+    def _make(start_date, end_date):
+        # Jump forward from the start_date...
+        while True:
+            yield start_date
+            # ... one day at a time ...
+            start_date = start_date + datetime.timedelta(days=1)
+            # ... until you reach the end date.
+            if start_date > end_date:
+                break
+                
     # Verify that the start_date comes after the end_date.
     if start_date > end_date:
         raise ValueError('You provided a start_date that comes after the end_date.')
-    
-    # Jump forward from the start_date...
-    while True:
-        yield start_date
-        # ... one day at a time ...
-        start_date = start_date + datetime.timedelta(days=1)
-        # ... until you reach the end date.
-        if start_date > end_date:
-            break
+    else:
+        return _make(start_date, end_date)
+
